==> dojo-1.10.6.tgz: package/cldr/nls/bs/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "MM.y.",
	"field-dayperiod": "pre podne/ popodne",
	"dayPeriods-format-wide-pm": "popodne",
	"field-minute": "minut",
	"eraNames": [
		"Pre nove ere",
		"Nove ere"
	],
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"field-weekday": "dan u nedelji",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-yQQQ": "y QQQ",
	"field-day-relative+-2": "prekjuče",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-MMM": "LLL",
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "čas",
	"dayPeriods-format-wide-am": "pre podne",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dateFormatItem-y": "y.",
	"timeFormat-full": "HH:mm:ss zzzz",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"avg",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dateFormatItem-Ed": "E, dd.",
	"dateFormatItem-yMMM": "MMM y.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"eraAbbr": [
		"p. n. e.",
		"n. e"
	],
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y.",
	"timeFormat-medium": "HH:mm:ss",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd.MM.y.",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-yMd": "dd.MM.y.",
	"quarters-standAlone-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"field-week": "nedelja",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"avgust",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"dateFormatItem-MMMd": "dd. MMM",
	"timeFormat-long": "HH:mm:ss z",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"avg",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-short": "HH:mm",
	"field-month": "mesec",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-M": "L",
	"dateFormatItem-yMMMd": "dd. MMM y.",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-MEd": "E, dd.MM.",
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-hm": "hh:mm a",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-short": "dd.MM.yy.",
	"dateFormatItem-yMMMEd": "E, dd. MMM y.",
	"dateFormat-full": "EEEE, dd. MMMM y.",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yMEd": "E, dd.MM.y.",
	"months-format-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"avgust",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d",
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"eraNarrow": [
		"p. n. e.",
		"n. e"
	]
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/bs/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yM": "MM.y.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"dayPeriods-format-wide-pm": "popodne",
	"field-minute": "minut",
	"eraNames": [
		"Prije nove ere",
		"Nove ere"
	],
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"field-weekday": "dan u sedmici",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-yQQQ": "y QQQ",
	"field-day-relative+-2": "prekjuče",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-MMM": "LLL",
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "sat",
	"dayPeriods-format-wide-am": "prije podne",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dateFormatItem-y": "y.",
	"timeFormat-full": "HH:mm:ss zzzz",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dateFormatItem-Ed": "E, dd.",
	"dateFormatItem-yMMM": "MMM y.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"eraAbbr": [
		"p. n. e.",
		"n. e."
	],
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y.",
	"timeFormat-medium": "HH:mm:ss",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd. MMM. y.",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-yMd": "dd.MM.y.",
	"quarters-standAlone-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"field-week": "sedmica",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"dateFormatItem-MMMd": "dd. MMM",
	"timeFormat-long": "HH:mm:ss z",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-short": "HH:mm",
	"field-month": "mjesec",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-M": "L",
	"dateFormatItem-yMMMd": "dd. MMM y.",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-MEd": "E, dd.MM.",
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-hm": "hh:mm a",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-short": "dd.MM.yy.",
	"dateFormatItem-yMMMEd": "E, dd. MMM y.",
	"dateFormat-full": "EEEE, dd. MMMM y.",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yMEd": "E, dd.MM.y.",
	"months-format-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d",
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"eraNarrow": [
		"p. n. e.",
		"n. e."
	]
}
//end v1.x content
);
